pub struct AtlasEntrypoint {
pub name: String,
pub kind: String,
pub trigger: String,
pub symbol: String,
}Fields
name: Stringkind: Stringtrigger: Stringsymbol: StringTrait Implementations
Sourceimpl Clone for AtlasEntrypoint
impl Clone for AtlasEntrypoint
Sourceimpl Debug for AtlasEntrypoint
impl Debug for AtlasEntrypoint
Sourceimpl<'de> Deserialize<'de> for AtlasEntrypoint
impl<'de> Deserialize<'de> for AtlasEntrypoint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AtlasEntrypoint
impl JsonSchema for AtlasEntrypoint
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AtlasEntrypoint
impl RefUnwindSafe for AtlasEntrypoint
impl Send for AtlasEntrypoint
impl Sync for AtlasEntrypoint
impl Unpin for AtlasEntrypoint
impl UnsafeUnpin for AtlasEntrypoint
impl UnwindSafe for AtlasEntrypoint