pub struct AtlasFlow {
pub name: String,
pub kind: FlowKind,
pub trigger: Option<String>,
pub steps: Vec<String>,
}Expand description
A condensed flow: steps collapsed to “Actor: operation” lines, with branch/async/failure markers preserved.
Fields
name: Stringkind: FlowKindtrigger: Option<String>steps: Vec<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for AtlasFlow
impl<'de> Deserialize<'de> for AtlasFlow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AtlasFlow
impl JsonSchema for AtlasFlow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AtlasFlow
impl RefUnwindSafe for AtlasFlow
impl Send for AtlasFlow
impl Sync for AtlasFlow
impl Unpin for AtlasFlow
impl UnsafeUnpin for AtlasFlow
impl UnwindSafe for AtlasFlow