pub struct AtlasHierarchyNode {
pub id: String,
pub name: String,
pub kind: String,
pub members: Vec<String>,
}Expand description
One hierarchical container (service or subsystem) with its direct member
entity ids (component ids, or subsystem ids nested inside a service).
Deterministic: members sorted by entity id.
Fields
id: StringContainer entity id (repo://…/service/… or repo://…/subsystem/…).
name: Stringkind: String"service" | "subsystem"
members: Vec<String>Trait Implementations
Sourceimpl Clone for AtlasHierarchyNode
impl Clone for AtlasHierarchyNode
Sourceimpl Debug for AtlasHierarchyNode
impl Debug for AtlasHierarchyNode
Sourceimpl<'de> Deserialize<'de> for AtlasHierarchyNode
impl<'de> Deserialize<'de> for AtlasHierarchyNode
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AtlasHierarchyNode
impl JsonSchema for AtlasHierarchyNode
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AtlasHierarchyNode
impl RefUnwindSafe for AtlasHierarchyNode
impl Send for AtlasHierarchyNode
impl Sync for AtlasHierarchyNode
impl Unpin for AtlasHierarchyNode
impl UnsafeUnpin for AtlasHierarchyNode
impl UnwindSafe for AtlasHierarchyNode