pub struct AtlasInvariant {
pub statement: String,
pub severity: Severity,
}Fields
statement: Stringseverity: SeverityTrait Implementations
Sourceimpl Clone for AtlasInvariant
impl Clone for AtlasInvariant
Sourceimpl Debug for AtlasInvariant
impl Debug for AtlasInvariant
Sourceimpl<'de> Deserialize<'de> for AtlasInvariant
impl<'de> Deserialize<'de> for AtlasInvariant
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AtlasInvariant
impl JsonSchema for AtlasInvariant
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AtlasInvariant
impl RefUnwindSafe for AtlasInvariant
impl Send for AtlasInvariant
impl Sync for AtlasInvariant
impl Unpin for AtlasInvariant
impl UnsafeUnpin for AtlasInvariant
impl UnwindSafe for AtlasInvariant