pub struct AtlasOwnershipClaim {
pub target: String,
pub provenance: String,
}Expand description
A typed ownership claim (provenance preserved — DECLARED intent never promoted).
Fields
target: Stringprovenance: StringTrait Implementations
Sourceimpl Clone for AtlasOwnershipClaim
impl Clone for AtlasOwnershipClaim
Sourceimpl Debug for AtlasOwnershipClaim
impl Debug for AtlasOwnershipClaim
Sourceimpl<'de> Deserialize<'de> for AtlasOwnershipClaim
impl<'de> Deserialize<'de> for AtlasOwnershipClaim
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AtlasOwnershipClaim
impl JsonSchema for AtlasOwnershipClaim
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AtlasOwnershipClaim
impl RefUnwindSafe for AtlasOwnershipClaim
impl Send for AtlasOwnershipClaim
impl Sync for AtlasOwnershipClaim
impl Unpin for AtlasOwnershipClaim
impl UnsafeUnpin for AtlasOwnershipClaim
impl UnwindSafe for AtlasOwnershipClaim