pub struct FlowStep {
pub id: String,
pub order: u32,
pub actor: String,
pub operation: String,
pub condition: Option<String>,
pub async: Option<bool>,
pub timeout_ms: Option<u64>,
pub retry_policy: Option<String>,
pub failure_outcome: Option<String>,
pub provenance: Option<Provenance>,
pub evidence: Vec<String>,
}Fields
id: Stringorder: u32actor: Stringoperation: Stringcondition: Option<String>async: Option<bool>timeout_ms: Option<u64>retry_policy: Option<String>failure_outcome: Option<String>provenance: Option<Provenance>evidence: Vec<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for FlowStep
impl<'de> Deserialize<'de> for FlowStep
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FlowStep
impl JsonSchema for FlowStep
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FlowStep
impl RefUnwindSafe for FlowStep
impl Send for FlowStep
impl Sync for FlowStep
impl Unpin for FlowStep
impl UnsafeUnpin for FlowStep
impl UnwindSafe for FlowStep