pub struct Invariant {
pub id: String,
pub statement: String,
pub severity: Severity,
pub scope: Vec<String>,
pub enforced_by: Vec<String>,
pub provenance: Option<Provenance>,
pub evidence: Vec<String>,
}Fields
id: Stringstatement: Stringseverity: Severityscope: Vec<String>enforced_by: Vec<String>provenance: Option<Provenance>evidence: Vec<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Invariant
impl<'de> Deserialize<'de> for Invariant
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Invariant
impl JsonSchema for Invariant
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Invariant
impl RefUnwindSafe for Invariant
impl Send for Invariant
impl Sync for Invariant
impl Unpin for Invariant
impl UnsafeUnpin for Invariant
impl UnwindSafe for Invariant