pub struct SemanticParameter {
pub name: String,
pub ty: Option<String>,
pub receiver: bool,
pub default: Option<String>,
pub variadic: bool,
}Expand description
One function/method parameter in structured form.
Fields
name: Stringty: Option<String>receiver: bool&self / self receiver parameters.
default: Option<String>variadic: boolTrait Implementations
Sourceimpl Clone for SemanticParameter
impl Clone for SemanticParameter
Sourceimpl Debug for SemanticParameter
impl Debug for SemanticParameter
Sourceimpl<'de> Deserialize<'de> for SemanticParameter
impl<'de> Deserialize<'de> for SemanticParameter
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SemanticParameter
impl JsonSchema for SemanticParameter
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SemanticParameter
impl PartialEq for SemanticParameter
Sourceimpl Serialize for SemanticParameter
impl Serialize for SemanticParameter
impl StructuralPartialEq for SemanticParameter