pub struct SurfaceRank {
pub task_ppr: f64,
pub global_ppr: f64,
pub lexical: f64,
pub semantic: f64,
pub confidence: f64,
pub criticality: f64,
pub change_risk: f64,
pub novelty: f64,
pub total: f64,
pub reasons: Vec<String>,
}Expand description
Why a surface entry earned its rank (explainability; scc surface --explain renders this).
Fields
task_ppr: f64global_ppr: f64lexical: f64semantic: f64confidence: f64criticality: f64change_risk: f64novelty: f64total: f64reasons: Vec<String>Trait Implementations
Sourceimpl Clone for SurfaceRank
impl Clone for SurfaceRank
Sourceimpl Debug for SurfaceRank
impl Debug for SurfaceRank
Sourceimpl Default for SurfaceRank
impl Default for SurfaceRank
Sourceimpl<'de> Deserialize<'de> for SurfaceRank
impl<'de> Deserialize<'de> for SurfaceRank
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SurfaceRank
impl JsonSchema for SurfaceRank
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SurfaceRank
impl PartialEq for SurfaceRank
Sourceimpl Serialize for SurfaceRank
impl Serialize for SurfaceRank
impl StructuralPartialEq for SurfaceRank